@@ -645,30 +645,30 @@ class Command(BaseCommand):
         output('[green]解读模型配置已保存至[/green] {}'.format(config_path))
 
     def _install_sdk(self):
-        with console.status("正在安装 bge-python-sdk", spinner="earth"):
-            config_path = self.get_model_config_path()
-            config = get_config_parser(config_path)
-            section_name = DEFAULT_MODEL_SECTION
-            model_id = config_get(config.get, section_name, 'model_id')
-            runtime = config_get(config.get, section_name, 'runtime')
-            client = self._get_docker_client()
-            command = (
-                'pip install --cache-dir /tmp/.cache/ --no-deps '
-                'bge-python-sdk pimento requests_toolbelt -t /code/lib'
-            )
-            image_name = RUNTIMES[runtime]
-            self._get_or_pull_image(client, image_name)
-            output('开始安装模型依赖包...')
-            command = ('sh -c "{}"').format(command)
-            container_name = generate_container_name(model_id)
-            self._force_remove_container(client, container_name)
-            self._run_by_container(
-                client,
-                image_name,
-                command,
-                container_name
-            )
-            output('[green]安装完成[/green]')
+        output("正在安装 bge-python-sdk")
+        config_path = self.get_model_config_path()
+        config = get_config_parser(config_path)
+        section_name = DEFAULT_MODEL_SECTION
+        model_id = config_get(config.get, section_name, 'model_id')
+        runtime = config_get(config.get, section_name, 'runtime')
+        client = self._get_docker_client()
+        command = (
+            'pip install --cache-dir /tmp/.cache/ --no-deps '
+            'bge-python-sdk pimento requests_toolbelt -t /code/lib'
+        )
+        image_name = RUNTIMES[runtime]
+        self._get_or_pull_image(client, image_name)
+        output('开始安装模型依赖包...')
+        command = ('sh -c "{}"').format(command)
+        container_name = generate_container_name(model_id)
+        self._force_remove_container(client, container_name)
+        self._run_by_container(
+            client,
+            image_name,
+            command,
+            container_name
+        )
+        output('[green]安装完成[/green]')
 
     def upload_model_expfs(self, args):
         home = get_home()
@@ -857,18 +857,19 @@ class Command(BaseCommand):
                 filepath = total_files[zip_relpath]
                 if zip_relpath in minify_relpaths:
                     continue
-                ziph.write(filepath, zip_relpath)
+                zipinfo = zipfile.ZipInfo(zip_relpath)
+                zipinfo.external_attr = 0o755 << 16
+                with open(filepath, 'rb') as f:
+                    ziph.writestr(zipinfo, f.read())
                 output('\t{}'.format(zip_relpath))
             for zip_relpath in sorted(minify_relpaths):
                 filepath = total_files[zip_relpath]
                 with open(filepath, 'r') as fp:
                     content = fp.read()
-                with tempfile.NamedTemporaryFile(mode='w') as temp_fp:
-                    content = python_minifier.minify(content)
-                    temp_fp.write(content)
-                    temp_fp.flush()
-                    temp_fp.seek(0)
-                    ziph.write(temp_fp.name, zip_relpath)
+                content = python_minifier.minify(content)
+                zipinfo = zipfile.ZipInfo(zip_relpath)
+                zipinfo.external_attr = 0o755 << 16
+                ziph.writestr(zipinfo, content)
                 output('\t{} [green]MINIFIED[/green]'.format(zip_relpath))
 
     def get_ignore_patterns(self, home):
